'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _postcss = require('postcss');

var _postcss2 = _interopRequireDefault(_postcss);

var _properties = require('./properties');

var _properties2 = _interopRequireDefault(_properties);

var _values = require('./values');

var _values2 = _interopRequireDefault(_values);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

exports.default = _postcss2.default.plugin('postcss-german-stylesheets', function (opts) {
  opts = opts || {};

  return function (css) {
    css.walkDecls(function (decl) {
      /**
       * Convert Properties
       */
      Object.keys(_properties2.default).forEach(function (property) {
        if (decl.prop === _properties2.default[property]) {
          decl.prop = property;
        }
      });

      /**
       * Convert Values
       */
      Object.keys(_values2.default).forEach(function (value) {
        decl.value = decl.value.replace(_values2.default[value], value);
      });

      /**
       * Convert "!wichtig"
       */
      if (decl.value.indexOf('!wichtig') >= 0) {
        decl.value = decl.value.replace(/\s*!wichtig\s*/, '');
        decl.important = true;
      }
    });
  };
});
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = {
  'animation-delay': 'animationsverzögerung',
  'animation-direction': 'animationsrichtung',
  'animation-duration': 'animationsdauer',
  'animation-fill-mode': 'animationsfüllmethode',
  'animation-iteration-count': 'animationswiederholungsanzahl',
  'animation-name': 'animationsname',
  'animation-play-state': 'animationsabspielzustand',
  'animation-timing-function': 'animationstimingfunktion',
  'animation': 'animation',
  'background-attachment': 'hintergrundbefestigung',
  'background-clip': 'hintergrundbeschnitt',
  'background-color': 'hintergrundfarbe',
  'background-image': 'hintergrundbild',
  'background-origin': 'hintergrundursprung',
  'background-position': 'hintergrundposition',
  'background-repeat': 'hintergrundwiederholung',
  'background-size': 'hintergrundgröße',
  'background': 'hintergrund',
  'border-bottom-color': 'rahmenfarbe-unten',
  'border-bottom-left-radius': 'rahmenradius-unten-links',
  'border-bottom-right-radius': 'rahmenradius-unten-rechts',
  'border-bottom-style': 'rahmenstil-unten',
  'border-bottom-width': 'rahmenbreite-unten',
  'border-bottom': 'rahmen-unten',
  'border-collapse': 'rahmen-zusammenfallen',
  'border-color': 'rahmenfarbe',
  'border-image': 'bilderrahmen',
  'border-image-outset': 'bilderrahmen-anfang',
  'border-image-repeat': 'bilderrahmen-wiederholung',
  'border-image-slice': 'bilderrahmen-schnitt',
  'border-image-source': 'bilderrahmen-quelle',
  'border-image-width': 'bilderrahmen-breite',
  'border-left-color': 'rahmenfarbe-links',
  'border-left-style': 'rahmenstil-links',
  'border-left-width': 'rahmenbreite-links',
  'border-left': 'rahmen-links',
  'border-radius': 'rahmenradius',
  'border-right-color': 'rahmenfarbe-rechts',
  'border-right-style': 'rahmenstil-rechts',
  'border-right-width': 'rahmenbreite-rechts',
  'border-right': 'rahmen-rechts',
  'border-spacing': 'rahmenabstand',
  'border-style': 'rahmenstil',
  'border-top-color': 'rahmenfarbe-oben',
  'border-top-left-radius': 'rahmenradius-oben-links',
  'border-top-right-radius': 'rahmenradius-oben-rechts',
  'border-top-style': 'rahmenstil-oben',
  'border-top-width': 'rahmenbreite-oben',
  'border-top': 'rahmen-oben',
  'border-width': 'rahmenbreite',
  'border': 'rahmen',
  'bottom': 'unten',
  'box-shadow': 'kastenschatten',
  'box-sizing': 'kastenbemessung',
  'caption-side': 'beschriftungsseite',
  'clear': 'klären',
  'clip': 'ausschnitt',
  'color': 'farbe',
  'columns': 'spalten',
  'column-count': 'spaltenanzahl',
  'column-fill': 'spaltenfüllung',
  'column-gap': 'spaltenlücke',
  'column-rule': 'spaltenlinie',
  'column-rule-color': 'spaltenlinienfarbe',
  'column-rule-style': 'spaltenlinienstil',
  'column-rule-width': 'spaltenlinienbreite',
  'column-span': 'spaltenspanne',
  'column-width': 'spaltenbreite',
  'content': 'inhalt',
  'counter-increment': 'zähler-erhöhen',
  'counter-reset': 'zähler-zurücksetzen',
  'cursor': 'zeiger',
  'display': 'anzeige',
  'empty-cells': 'leere-zellen',
  'filter': 'filter',
  'flex-basis': 'flex-grundlage',
  'flex-direction': 'flex-richtung',
  'flex-flow': 'flex-fluss',
  'flex-grow': 'flex-wachsen',
  'flex-shrink': 'flex-schrumpfen',
  'flex-wrap': 'flex-umbruch',
  'flex': 'flex',
  'float': 'umlaufen',
  'font-family': 'schriftfamilie',
  'font-feature-settings': 'schrifteigenschaften-einstellungen',
  'font-size': 'schriftgröße',
  'font-size-adjust': 'schriftgröße-anpassen',
  'font-style': 'schriftstil',
  'font-variant': 'schriftvariante',
  'font-weight': 'schriftgewicht',
  'font': 'schrift',
  'height': 'höhe',
  'hyphens': 'trennstriche',
  'justify-content': 'inhalt-ausrichten',
  'left': 'links',
  'letter-spacing': 'zeichenabstand',
  'line-break': 'zeilenumbruch',
  'line-height': 'zeilenhöhe',
  'list-style-image': 'listenbildstil',
  'list-style-position': 'listenpositionsstil',
  'list-style-type': 'listentypstil',
  'list-style': 'listenstil',
  'margin-bottom': 'außenabstand-unten',
  'margin-left': 'außenabstand-links',
  'margin-right': 'außenabstand-rechts',
  'margin-top': 'außenabstand-oben',
  'margin': 'außenabstand',
  'max-height': 'max-höhe',
  'max-width': 'max-breite',
  'min-height': 'min-höhe',
  'min-width': 'min-breite',
  'opacity': 'deckkraft',
  'order': 'reihenfolge',
  'orphans': 'schusterjungen',
  'outline-color': 'konturfarbe',
  'outline-offset': 'konturabstand',
  'outline-style': 'konturstil',
  'outline-width': 'konturbreite',
  'outline': 'kontur',
  'overflow-x': 'überlauf-x',
  'overflow-y': 'überlauf-y',
  'overflow': 'überlauf',
  'padding-bottom': 'innenabstand-unten',
  'padding-left': 'innenabstand-left',
  'padding-right': 'innenabstand-rechts',
  'padding-top': 'innenabstand-oben',
  'padding': 'innenabstand',
  'perspective-origin': 'ursprungsperspektive',
  'perspective': 'perspektive',
  'pointer-events': 'ereigniszeiger',
  'position': 'position',
  'quotes': 'anführungszeichen',
  'resize': 'größenänderung',
  'right': 'rechts',
  'table-layout': 'tabellengestaltung',
  'tab-size': 'tabgröße',
  'text-align': 'textausrichten',
  'text-decoration': 'textverzierung',
  'text-indent': 'texteinrückung',
  'text-orientation': 'textorientierung',
  'text-overflow': 'textüberlauf',
  'text-rendering': 'textwiedergabe',
  'text-shadow': 'textschatten',
  'text-transform': 'textumformung',
  'top': 'oben',
  'transition-delay': 'übergangsverzögerung',
  'transition-duration': 'übergangsdauer',
  'transition-property': 'übergangseigenschaft',
  'transition-timing-function': 'übergangstaktfunktion',
  'transition': 'übergang',
  'unicode-bidi': 'unicode-bidi',
  'vertical-align': 'vertikale-ausrichtung',
  'visibility': 'sichtbarkeit',
  'white-space': 'weißraum',
  'widows': 'witwen',
  'width': 'breite',
  'word-break': 'wortumbruch',
  'word-spacing': 'wortabstand',
  'word-wrap': 'wortumschlag',
  'writing-mode': 'schreibrichtung',
  'z-index': 'ebene'
};
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = {
  'absolute': 'absolut',
  'auto': 'automatisch',
  'bold': 'fett',
  'fixed': 'fixiert',
  'hidden': 'versteckt',
  'inherit': 'erben',
  'initial': 'initial',
  'italic': 'kursiv',
  'left': 'links',
  'no-repeat': 'nicht-wiederholen',
  'none': 'keines',
  'relative': 'relativ',
  'repeat-x': 'wiederholen-x',
  'repeat-y': 'wiederholen-y',
  'repeat': 'wiederholen',
  'right': 'rechts',
  'solid': 'durchgezogen',
  'static': 'statisch',
  'unset': 'aufheben',

  /**
   * Colors
   */
  'aliceblue': 'eisfarben',
  'antiquewhite': 'antikweiß',
  'aqua': 'wasser',
  'aquamarine': 'aquamarinblau',
  'beige': 'beige',
  'bisque': 'biskuit',
  'blanchedalmond': 'mandelweiß',
  'blueviolet': 'blauviolett',
  'burlywood': 'gelbbraun',
  'cadetblue': 'kadettenblau',
  'chocolate': 'schokolade',
  'cornflowerblue': 'kornblumenblau',
  'cornsilk': 'mais',
  'crimson': 'karmesinrot',
  'darkblue': 'dunkelblau',
  'darkcyan': 'dunkeltürkis',
  'darkgoldenrod': 'dunklegoldrunenfarbe',
  'darkgreen': 'dunkelgrün',
  'darkgray': 'dunkelgrau',
  'darkkhaki': 'dunkelkhaki',
  'darkmagenta': 'dunkelmagenta',
  'darkolivegreen': 'dunkelolivgrün',
  'darkorange': 'dunkelorange',
  'darkorchid': 'dunkleorchidee',
  'darkred': 'dunkelrot',
  'darksalmon': 'dunklelachsfarbe',
  'darkseagreen': 'dunklesseegrün',
  'darkslateblue': 'dunklesschieferblau',
  'darkviolet': 'dunkelviolett',
  'deeppink': 'tiefrosa',
  'deepskyblue': 'tiefhimmelblau',
  'dimgrey': 'gedimmtesgrau',
  'dodgerblue': 'persinningblau',
  'firebrick': 'backstein',
  'floralwhite': 'blütenweiß',
  'forestgreen': 'waldgrün',
  'ghostwhite': 'geisterweiß',
  'greenyellow': 'grüngelb',
  'honeydew': 'honigmelone',
  'hotpink': 'leuchtendrosa',
  'indianred': 'indischrot',
  'ivory': 'elfenbein',
  'khaki': 'staubfarbend',
  'lavenderblush': 'lavendelrosa',
  'lawngreen': 'grasgrün',
  'lemonchiffon': 'chiffongelb',
  'lightblue': 'hellblau',
  'lightcoral': 'helleskorallenrot',
  'lightcyan': 'helltürkis',
  'lightgray': 'hellgrau',
  'lightgreen': 'hellgrün',
  'lightpink': 'hellrosa',
  'lightsalmon': 'hellelachsfarbe',
  'lightseagreen': 'hellesseegrün',
  'lightskyblue': 'helleshimmelblau',
  'lightslategray': 'hellesschiefergrau',
  'lightsteelblue': 'hellesstahlblau',
  'lightyellow': 'hellgelb',
  'limegreen': 'limonengrün',
  'linen': 'leinen',
  'maroon': 'kastanie',
  'midnightblue': 'mitternachtsblau',
  'mintcream': 'cremigeminze',
  'mistyrose': 'altrosa',
  'moccasin': 'mokassin',
  'navajowhite': 'navajoweiß',
  'navy': 'marineblau',
  'oldlace': 'altespitze',
  'olivedrab': 'olivgrünbraun',
  'orangered': 'orangerot',
  'orchid': 'orchidee',
  'palegoldenrod': 'blassegoldrunenfarbe',
  'palegreen': 'blassgrün',
  'paleturquoise': 'blasstürkis',
  'papayawhip': 'papayacreme',
  'peachpuff': 'pfirsich',
  'plum': 'pflaume',
  'powderblue': 'taubenblau',
  'purple': 'violett',
  'rosybrown': 'rosigesbraun',
  'royalblue': 'royalblau',
  'saddlebrown': 'sattelbraun',
  'salmon': 'lachsfarben',
  'sandybrown': 'sandbraun',
  'seagreen': 'seegrün',
  'seashell': 'muschel',
  'sienna': 'siennaerde',
  'silver': 'silber',
  'slateblue': 'schieferblau',
  'slategray': 'schiefergrau',
  'snow': 'schneeweiß',
  'springgreen': 'frühlingsgrün',
  'steelblue': 'stahlblau',
  'tan': 'hautfarben',
  'teal': 'krickentengrün',
  'thistle': 'distel',
  'tomato': 'tomate',
  'turquoise': 'türkis',
  'violet': 'veilchen',
  'wheat': 'weizen',
  'whitesmoke': 'rauchfarben',
  'yellowgreen': 'gelbgrün',
  'azure': 'himmelblau',
  'black': 'schwarz',
  'blue': 'blau',
  'coral': 'koralle',
  'cyan': 'cyan',
  'gray': 'grau',
  'green': 'grün',
  'pink': 'rosa',
  'lavender': 'lavendel',
  'lime': 'limone',
  'orange': 'orange',
  'red': 'rot',
  'white': 'weiß',
  'yellow': 'gelb'
};
